@@ -4,9 +4,11 @@ Framework for running analysis over patient data.
 This module provides for construction of an analysis application
 as a sequence of algorithms, each of which inherits from the
 Algorithm class.  This defines three methods relating to execution:
-    initialise - run before any patient data are read;
-    execute - run once for each patient;
-    finalise - run after all patient data have been read.
+
+* **initialise()** - run before any patient data are read;
+* **execute()** - run once for each patient;
+* **finalise()** - run after all patient data have been read.
+
 Each method returns an instance of the Status class,
 providing information on whether execution problems were encountered.
 Running of algorithm methods is handled by the Application class.
@@ -24,25 +26,27 @@ class Algorithm():
     overwriting as needed the methods initialise, execute, finalise,
     to implement analysis-specific functionality.
 
-    Methods
-    -------
-    __init__ : Create instance of Algorithm class.
-    initialise : Perform tasks required before considering any patients.
-    execute : Perform tasks required for each patient.
-    finalise : Perform tasks required after considering all patients.
-    set_attributes: Set values for algorithm attributes.
+    **Methods:**
+
+    * **__init__()**: Create instance of Algorithm class.
+    * **initialise()**: Perform tasks required before considering any patients.
+    * **execute()**: Perform tasks required for each patient.
+    * **finalise()**: Perform tasks required after considering all patients.
+    * **set_attributes()**: Set values for algorithm attributes.
     '''
 
     def __init__(self, opts={}, name=None, log_level=None):
         '''
         Create instance of Algorithm class.
 
-        Parameters
-        ----------
-        opts : dict, default={}
+        **Parameters:**
+
+        opts: dict, default={}
             Dictionary for setting algorithm attributes.
-        name : str, default=''
+
+        name: str, default=''
             Name for identifying algorithm instance.
+
         log_level: str/int/None, default=None
             Severity level for event logging.  If the value is None,
             log_level is set to the value of skrt.core.Defaults().log_level.
@@ -58,17 +62,19 @@ class Algorithm():
         # Initialise algorithm attributes.
         self.set_attributes(opts)
 
-        return None
-
     def execute(self, patient=None):
         '''
         Perform tasks required for each patient.
 
-        Parameter
-        ---------
-        patient : skrt.patient.Patient/None, default=None
+        **Parameter:**
+
+        patient: skrt.patient.Patient/None, default=None
             Object providing access to patient information.
         '''
+
+        # Print patient identifier and path
+        print(f'{patient.id}: {patient.path}')
+
         return self.status
 
     def finalise(self):
@@ -87,40 +93,37 @@ class Algorithm():
         '''
         Set values for algorithm attributes.
 
-        Parameter
-        ----------
-        opts : dict, default={}
+        **Parameter:**
+
+        opts: dict, default={}
             Dictionary for setting algorithm attributes.
         '''
         for key in opts:
             setattr(self, key, opts[key])
-        return None
 
 class Application():
     '''
     Represent application as sequence of algorithm, and manage execution.
 
-    Methods
-    -------
-    __init__ - Create instance of Application class.
-    initialise - Call each algorithm's initialise method.
-    execute - For each patient, call each algorithm's execute method.
-    finalise - Call each algorithm's finalise method.
-    run - Initialise analysis, process patient data, finalise analysis.
+    **Methods:**
+
+    * **__init__()**: Create instance of Application class.
+    * **initialise()**: Call each algorithm's initialise method.
+    * **execute()**: For each patient, call each algorithm's execute method.
+    * **finalise()**: Call each algorithm's finalise method.
+    * **run()**: Initialise analysis, process patient data, finalise analysis.
     '''
 
     def __init__(self, algs=[], log_level=None):
         '''
         Create instance of Application class.
 
-        Parameters
-        ----------
-        algs : list, default=[]
+        **Parameters:**
+
+        algs: list, default=[]
             List of algorithms to be managed.  Algorithms are processed
             in the order in which they are specified in the list.
-        log_level: str/int/None, default=None
-            Severity level for event logging.
-            If set to None, the value of core.Defaults().log_level is used.
+
         log_level: str/int/None, default=None
             Severity level for event logging.  If the value is None,
             log_level is set to the value of skrt.core.Defaults().log_level.
@@ -136,9 +139,10 @@ class Application():
         '''
         For each patient, call each algorithm's execute method.
 
-        Parameter
-        ---------
-        patient : skrt.patient.Patient/None, default=None
+        **Parameter:**
+
+        patient: skrt.patient.Patient/None, default=None
+
             Object providing access to patient information.
         '''
         for alg in self.algs:
@@ -184,17 +188,17 @@ class Application():
         '''
         Initialise analysis, process patient data, finalise analysis.
 
-        Parameter
-        ---------
-        paths : list, default = []
+        **Parameter:**
+
+        paths: list, default = []
             List of paths to folders containing patient data.
         '''
 
         if self.status.ok():
             if not paths:
                 self.logger.warning('List of paths to patient data is empty')
-            for dataPath in paths:
-                patient = Patient(path=dataPath)
+            for data_path in paths:
+                patient = Patient(path=data_path)
                 self.status = self.execute(patient=patient)
                 if not self.status.ok():
                     break
@@ -209,10 +213,10 @@ class Status():
     '''
     Represent an exit status.
 
-    Methods
-    -------
-    __init__ : Create instance of Status class.
-    OK : Return boolean, indicating whether status is okay.
+    **Methods:**
+
+    * **__init__()**: Create instance of Status class.
+    * **ok()**: Return boolean, indicating whether status is okay.
     '''
 
     def __init__(self, code=0, name='', reason=''):
@@ -222,19 +226,20 @@ class Status():
         Instances of the Status class are intended to be returned by
         algorithm methods, with attributes set to indicate exit status.
 
-        Parameters
-        ----------
-        code : int, default=0
+        **Parameters:**
+
+        code: int, default=0
             Value for exit status.
-        name : str, default=''
+
+        name: str, default=''
             Name for exit status.
-        reason : str, default=''
+
+        reason: str, default=''
             Reason for exit status.
         '''
         self.code = code
         self.name = name
         self.reason = reason
-        return None
 
     def ok(self):
         '''
